==> ys-sdk-0.7.3.tgz: package/README.md <==
## 小程序数据埋点

- 简要说明

  - 用于页面的数据埋点（UV、PV、停留时长、触达率等

- 项目构建
  - 打生产包：yarn build:ys
  - 打测试包：yarn build:ys_dev
  - [npm 包地址](https://www.npmjs.com/package/ys-sdk)

#### 接口说明

Usage

```js
// 生产环境
const yssdk = require("ys-sdk")("production");
// 测试环境
// const yssdk = require("ys-sdk")("test");

export interface ILogConfig {
  openId: string;
  userId: string;
  unionId: string;
  contentId: number;
  columnId: number;
  clientHeight: number;
  character: string; // 表示用户的角色，是促销员还是客户，"seller" 或者 "customer"
  sessionId?: string;
  title: string; // 内容或素材的名称，如："内容A"
  columnName: string; // 栏目名称，如果有多级栏目则用逗号分隔，如："栏目1,栏目2"
  keyWords?: string | null; // 关键词，如果有多个则用逗号分隔，如："关键词1,关键词2"，没有则不传或传 null
  contentCreateTime: string | number; // 内容的创建时间，传字符串或者时间戳，格式保持一致就行
  isShared: boolean; // 页面是分享出去的页面，则传 true，默认是 false
  sellerId?: string | number | null; // 分享者或直销员的ID，从分享出去的页面访问需要传入
  sellerName?: string | null; // 分享者或直销员的姓名，从分享出去的页面访问需要传入
  department?: string; // 直销员所属部门，或是门店名称，如："上海xxx店"
}

const log = new yssdk.Log(param: ILogConfig);
/**
 * 统计PV，页面加载完后调用
 */
log.event_page_pv();

/**
 * 跳失率，用户有触摸操作后调用
 */
log.event_page_loss_access();

/**
 * 阅读比例，页面加载完和滚动时调用
 */
log.event_page_send_position(scrollHeight: number, scrollTop: number);

/**
 * 页面停留时长，页面加载完后调用
 * @param {number} timeout 埋点请求触发频率，默认值 10000ms
 */
log.event_page_access_time(timeout?: number);

/**
 * 热力图，滚动时调用
 */
log.event_page_hotaccess_time(scrollHeight: number, scrollTop: number);

/**
 * 触发页面隐藏
 */
log.event_page_hide();

/**
 * 触发页面回显
 */
log.event_page_show();

/**
 * 触发页面卸载
 * 提供这个方法是为了在页面卸载时取消定时器
 */
log.event_page_unload();

/**
 ** 内容页点击有用
 */
log.event_page_useful();

/**
 * 点击下载按钮
 */
log.event_page_download();

/**
 * 点击分享按钮
 */
log.event_page_share();

/**
 * 专门用来更新 columnId 这个字段的方法
 * 因为之前有很多埋点数据缺失 columnId
 */
log.upgradeColumnId(columnId: number);
```

==> ys-sdk-0.8.5.tgz: package/README.md <==
## 小程序数据埋点

- 简要说明

  - 用于页面的数据埋点（UV、PV、停留时长、触达率等

- 项目构建
  - 打生产包：yarn build:ys
  - 打测试包：yarn build:ys_dev
  - [npm 包地址](https://www.npmjs.com/package/ys-sdk)

#### 接口说明

Usage

```js
// 使用生产环境接口
const yssdk = require("ys-sdk")("production");
// 使用测试环境接口
// const yssdk = require("ys-sdk")("test");

// 渠道枚举，目前的可选值
export enum SourceFrom {
  YISEN_AJN = "YISEN_AJN",
  YISEN_CONTENT_H5 = "YISEN_CONTENT_H5",
  HEYSHOP_CONSTELLATION_MINI = "HEYSHOP_CONSTELLATION_MINI"
}

export interface ILogConfig {
  openId: string;
  userId: string;
  unionId: string;
  contentId: number;
  columnId: number;
  clientHeight: number;
  character: string; // 表示用户的角色，是促销员还是客户，"seller" 或者 "customer"
  sessionId?: string;
  title: string; // 内容或素材的名称，如："内容A"
  columnName: string; // 栏目名称，如果有多级栏目则用逗号分隔，如："栏目1,栏目2"
  keyWords?: string | null; // 关键词，如果有多个则用逗号分隔，如："关键词1,关键词2"，没有则不传或传 null
  contentCreateTime: string | number; // 内容的创建时间，传字符串或者时间戳，格式保持一致就行
  isShared: boolean; // 页面是分享出去的页面，则传 true，默认是 false
  sellerId?: string | number | null; // 分享者或直销员的ID，从分享出去的页面访问需要传入
  sellerName?: string | null; // 分享者或直销员的姓名，从分享出去的页面访问需要传入
  department?: string; // 直销员所属部门，或是门店名称，如："上海xxx店"
  sourceFrom: SourceFrom | string; // 渠道来源，必传
}

const log = new yssdk.Log({
  openId: "aaa",
  userId: "bbb",
  unionId: "ccc",
  contentId: 567,
  columnId: 23,
  clientHeight: 666,
  character: "seller",
  title: "内容标题",
  columnName: "栏目1",
  keyWords: "关键词1,关键词2",
  contentCreateTime: 1604460370000,
  isShared: false,
  sellerId: 123,
  sellerName: "直销员1",
  department: "上海xxx门店",
  sourceFrom: yssdk.Log.SourceFrom.YISEN_AJN
});
/**
 * 统计PV，页面加载完后调用
 */
log.event_page_pv();

/**
 * 跳失率，用户有触摸操作后调用
 */
log.event_page_loss_access();

/**
 * 阅读比例，页面加载完和滚动时调用
 */
log.event_page_send_position(scrollHeight: number, scrollTop: number);

/**
 * 页面停留时长，页面加载完后调用
 * @param {number} timeout 埋点请求触发频率，默认值 10000ms
 */
log.event_page_access_time(timeout?: number);

/**
 * 热力图，滚动时调用
 */
log.event_page_hotaccess_time(scrollHeight: number, scrollTop: number);

/**
 * 触发页面隐藏
 */
log.event_page_hide();

/**
 * 触发页面回显
 */
log.event_page_show();

/**
 * 触发页面卸载
 * 提供这个方法是为了在页面卸载时取消定时器
 */
log.event_page_unload();

/**
 ** 内容页点击有用
 */
log.event_page_useful();

/**
 * 点击下载按钮
 */
log.event_page_download();

/**
 * 点击分享按钮
 */
log.event_page_share();

/**
 * 专门用来更新 columnId 这个字段的方法
 * 因为之前有很多埋点数据缺失 columnId
 */
log.upgradeColumnId(columnId: number);
```
